durationtools.numeric_seconds_to_clock_string
=============================================

.. autofunction:: abjad.tools.durationtools.numeric_seconds_to_clock_string.numeric_seconds_to_clock_string
